@@ -465,7 +465,11 @@ def picking_details(request_id):
     """
     picking = PickingRequest(request_id)
     response = picking.details()['content']
-    API_LOGS.logger.info(response)
+    # API_LOGS.logger.info(response)
+    response = {
+        "status": 200,
+        "data": response
+        }
 
     return jsonify(response)
 
